@@ -2,7 +2,7 @@ package net.lingala.zip4j.io.inputstream;
 
 class StoreInputStream extends DecompressedInputStream {
 
-  public StoreInputStream(CipherInputStream cipherInputStream) {
+  public StoreInputStream(CipherInputStream<?> cipherInputStream) {
     super(cipherInputStream);
   }
 }
