@@ -10,14 +10,15 @@ import static net.lingala.zip4j.util.InternalZipConstants.STD_DEC_HDR_SIZE;
 class ZipStandardCipherInputStream extends CipherInputStream<StandardDecrypter> {
 
   public ZipStandardCipherInputStream(ZipEntryInputStream zipEntryInputStream, LocalFileHeader localFileHeader,
-                                      char[] password, int bufferSize) throws IOException {
-    super(zipEntryInputStream, localFileHeader, password, bufferSize);
+                                      char[] password, int bufferSize, boolean useUtf8ForPassword) throws IOException {
+    super(zipEntryInputStream, localFileHeader, password, bufferSize, useUtf8ForPassword);
   }
 
   @Override
-  protected StandardDecrypter initializeDecrypter(LocalFileHeader localFileHeader, char[] password) throws IOException {
+  protected StandardDecrypter initializeDecrypter(LocalFileHeader localFileHeader, char[] password,
+                                                  boolean useUtf8ForPassword) throws IOException {
     return new StandardDecrypter(password, localFileHeader.getCrc(), localFileHeader.getLastModifiedTime(),
-        getStandardDecrypterHeaderBytes());
+        getStandardDecrypterHeaderBytes(), useUtf8ForPassword);
   }
 
   private byte[] getStandardDecrypterHeaderBytes() throws IOException {
