@@ -5,9 +5,9 @@ import java.io.OutputStream;
 
 abstract class CompressedOutputStream extends OutputStream {
 
-  private CipherOutputStream cipherOutputStream;
+  private CipherOutputStream<?> cipherOutputStream;
 
-  public CompressedOutputStream(CipherOutputStream cipherOutputStream) {
+  public CompressedOutputStream(CipherOutputStream<?> cipherOutputStream) {
     this.cipherOutputStream = cipherOutputStream;
   }
 
