@@ -1,7 +1,6 @@
 package net.lingala.zip4j.io.outputstream;
 
 import net.lingala.zip4j.crypto.Encrypter;
-import net.lingala.zip4j.exception.ZipException;
 import net.lingala.zip4j.model.ZipParameters;
 
 import java.io.IOException;
@@ -9,12 +8,14 @@ import java.io.OutputStream;
 
 class NoCipherOutputStream extends CipherOutputStream<NoCipherOutputStream.NoEncrypter> {
 
-  public NoCipherOutputStream(ZipEntryOutputStream zipEntryOutputStream, ZipParameters zipParameters, char[] password) throws IOException, ZipException {
-    super(zipEntryOutputStream, zipParameters, password);
+  public NoCipherOutputStream(ZipEntryOutputStream zipEntryOutputStream, ZipParameters zipParameters, char[] password)
+          throws IOException {
+    super(zipEntryOutputStream, zipParameters, password, true);
   }
 
   @Override
-  protected NoEncrypter initializeEncrypter(OutputStream outputStream, ZipParameters zipParameters, char[] password) {
+  protected NoEncrypter initializeEncrypter(OutputStream outputStream, ZipParameters zipParameters, char[] password,
+                                            boolean useUtf8ForPassword) {
     return new NoEncrypter();
   }
 
