@@ -2,7 +2,7 @@ package net.lingala.zip4j.io.outputstream;
 
 class StoreOutputStream extends CompressedOutputStream {
 
-  public StoreOutputStream(CipherOutputStream cipherOutputStream) {
+  public StoreOutputStream(CipherOutputStream<?> cipherOutputStream) {
     super(cipherOutputStream);
   }
 
