@@ -7,11 +7,16 @@ import net.lingala.zip4j.model.ZipModel;
 import net.lingala.zip4j.model.ZipParameters;
 import net.lingala.zip4j.progress.ProgressMonitor;
 import net.lingala.zip4j.tasks.AddFilesToZipTask.AddFilesToZipTaskParameters;
+import net.lingala.zip4j.util.FileUtils;
 
 import java.io.File;
 import java.io.IOException;
+import java.util.ArrayList;
 import java.util.List;
 
+import static net.lingala.zip4j.model.ZipParameters.SymbolicLinkAction.INCLUDE_LINK_ONLY;
+import static net.lingala.zip4j.util.FileUtils.isSymbolicLink;
+
 public class AddFilesToZipTask extends AbstractAddFileToZipTask<AddFilesToZipTaskParameters> {
 
   public AddFilesToZipTask(ZipModel zipModel, char[] password, HeaderWriter headerWriter,
@@ -24,7 +29,8 @@ public class AddFilesToZipTask extends AbstractAddFileToZipTask<AddFilesToZipTas
       throws IOException {
 
     verifyZipParameters(taskParameters.zipParameters);
-    addFilesToZip(taskParameters.filesToAdd, progressMonitor, taskParameters.zipParameters, taskParameters.zip4jConfig);
+    List<File> filesToAdd = determineActualFilesToAdd(taskParameters);
+    addFilesToZip(filesToAdd, progressMonitor, taskParameters.zipParameters, taskParameters.zip4jConfig);
   }
 
   @Override
@@ -32,6 +38,22 @@ public class AddFilesToZipTask extends AbstractAddFileToZipTask<AddFilesToZipTas
     return calculateWorkForFiles(taskParameters.filesToAdd, taskParameters.zipParameters);
   }
 
+  private List<File> determineActualFilesToAdd(AddFilesToZipTaskParameters taskParameters) throws ZipException {
+    List<File> filesToAdd = new ArrayList<>();
+
+    for (File inputFile : taskParameters.filesToAdd) {
+      filesToAdd.add(inputFile);
+      boolean isSymLink = isSymbolicLink(inputFile);
+      ZipParameters.SymbolicLinkAction symbolicLinkAction = taskParameters.zipParameters.getSymbolicLinkAction();
+      if (isSymLink && !INCLUDE_LINK_ONLY.equals(symbolicLinkAction)) {
+        filesToAdd.addAll(FileUtils.getFilesInDirectoryRecursive(inputFile, taskParameters.zipParameters));
+      }
+
+    }
+
+    return filesToAdd;
+  }
+
   @Override
   protected ProgressMonitor.Task getTask() {
     return super.getTask();
