@@ -98,6 +98,29 @@ public class HeaderUtilTest {
     assertThat(fileHeader.getFileName()).isEqualTo(FILE_NAME);
   }
 
+  @Test
+  public void testGetFileHeaderWithExactMatchCaseSensitive() throws ZipException {
+    final String lowerCaseFile = FILE_NAME.toLowerCase();
+    final String upperCaseFile = FILE_NAME.toUpperCase();
+    ZipModel zipModel = new ZipModel();
+    CentralDirectory centralDirectory = new CentralDirectory();
+    centralDirectory.setFileHeaders(Arrays.asList(
+            generateFileHeader(lowerCaseFile),
+            generateFileHeader(upperCaseFile)
+    ));
+    zipModel.setCentralDirectory(centralDirectory);
+
+    assertThat(centralDirectory.getFileHeaders()).hasSize(2);
+
+    FileHeader fileHeaderLower = HeaderUtil.getFileHeader(zipModel, lowerCaseFile);
+    assertThat(fileHeaderLower).isNotNull();
+    assertThat(fileHeaderLower.getFileName()).isEqualTo(lowerCaseFile);
+
+    FileHeader fileHeaderUpper = HeaderUtil.getFileHeader(zipModel, upperCaseFile);
+    assertThat(fileHeaderUpper).isNotNull();
+    assertThat(fileHeaderUpper.getFileName()).isEqualTo(upperCaseFile);
+  }
+
   @Test
   public void testGetFileHeaderWithWindowsFileSeparator() throws ZipException {
     ZipModel zipModel = new ZipModel();
